package com.landray.kmss.sys.attachment.thirdSfs.rest.controller;

import com.landray.kmss.util.SpringBeanUtil;
import org.springframework.web.bind.annotation.PathVariable;
import java.io.BufferedReader;
import java.util.List;
import com.landray.kmss.util.ResourceUtil;
import java.util.Arrays;
import com.landray.kmss.sys.attachment.model.SysAttConfig;
import com.landray.kmss.sys.mobile.util.MobileUtil;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.multipart.MultipartFile;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.GetMapping;
import com.landray.kmss.sys.attachment.thirdSfs.vo.ThirdSfsResponseResult;
import com.alibaba.fastjson.JSONObject;
import com.landray.kmss.util.StringUtil;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.http.HttpServletRequest;
import org.slf4j.LoggerFactory;
import com.landray.kmss.sys.attachment.integrate.wps.interfaces.ISysAttachmentWpsCenterOfficeProvider;
import org.slf4j.Logger;
import com.landray.kmss.web.annotation.RestApi;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.landray.kmss.sys.attachment.thirdSfs.rest.extend.SysAttExtendWpsCenterV6RestService;
import com.landray.kmss.sys.attachment.thirdSfs.rest.SysAttThirdController;

@RestController
@RequestMapping({ "/api/sys-attachment/wpsCenterV6" })
@RestApi(docUrl = "/sys/attachment/restservice/sysAttFoxitRestServiceHelp.jsp", name = "SysAttWpsCenterV6Controller", resourceKey = "sys-attachment:sysAttWpsCenterV6Controller.title")
public class SysAttWpsCenterV6Controller extends SysAttThirdController<SysAttExtendWpsCenterV6RestService>
{
    private static final Logger logger;
    private ISysAttachmentWpsCenterOfficeProvider wpsCenterProvider;
    
    static {
        logger = LoggerFactory.getLogger(SysAttWpsCenterV6Controller.class);
    }
    
    @GetMapping({ "/v1/3rd/file/info" })
    public Object fileInfo(final HttpServletRequest request, final HttpServletResponse response) throws Exception {
        final String fileId = request.getHeader("X-Weboffice-File-Id");
        String token = request.getHeader("X-Wps-Weboffice-Token");
        final String userId = request.getParameter("_w_third_userId");
        final String fdMode = request.getParameter("_w_third_fdMode");
        final String fs = request.getParameter("_w_third_fs");
        if (SysAttWpsCenterV6Controller.logger.isDebugEnabled()) {
            SysAttWpsCenterV6Controller.logger.debug("WPS中台回调获取文件信息开始, fileId = {}, userId= {}, fdMode = {}, fs = {}, token = {}", fileId, userId, fdMode, fs, token);
        }
        if ("1".equals(fs) && StringUtil.isNull(token)) {
            token = request.getParameter("_w_third_token");
            if (SysAttWpsCenterV6Controller.logger.isDebugEnabled()) {
                SysAttWpsCenterV6Controller.logger.debug("是forceSave前置回调, fileId = {}, userId= {}, fdMode = {}, fs = {}, token = {}", fileId, userId, fdMode, fs, token);
            }
        }
        if (!this.getWpsCenterProvider().isV6TokenValid(userId, token, fdMode)) {
            return this.buildErrResult(40003, "用户无权限访问", "用户无权限访问", null);
        }
        final JSONObject params = new JSONObject();
        params.put("fdId", (Object)fileId);
        params.put("token", (Object)token);
        params.put("userId", (Object)userId);
        params.put("fdMode", (Object)fdMode);
        params.put("curIp", (Object)request.getRemoteAddr());
        final ThirdSfsResponseResult result = ((SysAttExtendWpsCenterV6RestService)this.getSysAttExtendThirdRestService(request)).getFileInfo(params);
        if (SysAttWpsCenterV6Controller.logger.isDebugEnabled()) {
            SysAttWpsCenterV6Controller.logger.debug("WPS中台回调获取文件信息完成, result = {}", JSONObject.toJSONString((Object)result));
        }
        return result.getData();
    }
    
    private JSONObject buildErrResult(final Integer code, final String msg, final String detailMsg, final String hint) {
        final JSONObject result = new JSONObject();
        result.put("code", (Object)code);
        result.put("message", (Object)msg);
        result.put("details", (Object)detailMsg);
        if (StringUtil.isNotNull(hint)) {
            result.put("hint", (Object)hint);
        }
        return result;
    }
    
    @PostMapping({ "/v1/3rd/user/info" })
    public Object getUserInfos(final HttpServletRequest request, final HttpServletResponse response, @RequestBody final String ids) throws Exception {
        final String fileId = request.getHeader("X-Weboffice-File-Id");
        final String token = request.getHeader("X-Wps-Weboffice-Token");
        if (SysAttWpsCenterV6Controller.logger.isDebugEnabled()) {
            SysAttWpsCenterV6Controller.logger.debug("WPS中台回调获取用户信息开始, fileId = {}, ids= {}, token = {}", fileId, ids, token);
        }
        if (StringUtil.isNull(token)) {
            return this.buildErrResult(40003, "用户无权限访问", "用户无权限访问", null);
        }
        final JSONObject params = new JSONObject();
        params.put("ids", (Object)ids);
        params.put("fdId", (Object)fileId);
        params.put("token", (Object)token);
        final ThirdSfsResponseResult result = ((SysAttExtendWpsCenterV6RestService)this.getSysAttExtendThirdRestService(request)).getUserInfo(params);
        if (SysAttWpsCenterV6Controller.logger.isDebugEnabled()) {
            SysAttWpsCenterV6Controller.logger.debug("WPS中台回调获取用户信息完成, result = {}", JSONObject.toJSONString((Object)result));
        }
        return result.getData();
    }
    
    @GetMapping({ "/download" })
    public void download(final HttpServletRequest request, final HttpServletResponse response) throws Exception {
        final String fdId = request.getParameter("fdId");
        final String userId = request.getParameter("userId");
        final String key = request.getParameter("key");
        final String si = request.getParameter("si");
        if (SysAttWpsCenterV6Controller.logger.isDebugEnabled()) {
            SysAttWpsCenterV6Controller.logger.debug("WPS中台回调下载文件开始, fileId = {}, userId = {}, key = {}, si = {}", fdId, userId, key, si);
        }
        if (!this.getWpsCenterProvider().isV6DownloadTokenValid(userId, fdId, key, si)) {
            if (SysAttWpsCenterV6Controller.logger.isDebugEnabled()) {
                SysAttWpsCenterV6Controller.logger.debug("WPS中台回调下载文件失败, 无效的下载请求 fileId={}, userId={}, key={}, si={}", fdId, userId, key, si);
            }
            response.setStatus(401);
            return;
        }
        final JSONObject params = new JSONObject();
        params.put("emptyMapping", (Object)this.emptyMapping);
        params.put("request", (Object)request);
        params.put("response", (Object)response);
        this.getSysAttStandardThirdRestService(request).download(params);
        if (SysAttWpsCenterV6Controller.logger.isDebugEnabled()) {
            SysAttWpsCenterV6Controller.logger.debug("WPS中台回调下载文件完成, fileId = {}, userId= {}, si = {}", fdId, userId, si);
        }
    }
    
    @PostMapping({ "/v1/3rd/file/save" })
    public Object save(final HttpServletRequest request, final HttpServletResponse response, @RequestParam("file") final MultipartFile file) throws Exception {
        final boolean isMobile = MobileUtil.isMobile(request);
        final String fileId = request.getHeader("X-Weboffice-File-Id");
        String token = request.getHeader("X-Wps-Weboffice-Token");
        final String userId = request.getParameter("_w_third_userId");
        final String fdMode = request.getParameter("_w_third_fdMode");
        final String saveType = request.getHeader("X-Weboffice-Save-Type");
        final String version = request.getHeader("x-weboffice-save-version");
        final String saveFlag = request.getHeader("x-weboffice-save-caller");
        final SysAttConfig attConfig = new SysAttConfig();
        String saveCfg = attConfig.getDataMap().get("saveTypes");
        if (StringUtil.isNull(saveCfg)) {
            saveCfg = "OnSaveFile;onclose;submit";
        }
        if (SysAttWpsCenterV6Controller.logger.isDebugEnabled()) {
            SysAttWpsCenterV6Controller.logger.debug("WPS中台回调保存文件开始, isMobile = {}, fileId = {}, userId= {}, fdMode = {}, version = {}, saveType = {}, saveFlag = {}, saveCfg = {}, token = {}", isMobile, fileId, userId, fdMode, version, saveType, saveFlag, saveCfg, token);
        }
        if ("rollbackByVersion".equalsIgnoreCase(saveFlag)) {
            SysAttWpsCenterV6Controller.logger.warn("用户操作WPS中台恢复到指定历史版本开始, isMobile = {}, fileId = {}, userId= {}, fdMode = {}, version = {}, saveType = {}, saveFlag = {}, saveCfg = {}, token = {}", isMobile, fileId, userId, fdMode, version, saveType, saveFlag, saveCfg, token);
        }
        if ("rpc save".equalsIgnoreCase(saveFlag) && StringUtil.isNull(token)) {
            token = request.getParameter("_w_third_token");
            if (SysAttWpsCenterV6Controller.logger.isDebugEnabled()) {
                SysAttWpsCenterV6Controller.logger.debug("是forceSave, isMobile = {}, fileId = {}, userId= {}, fdMode = {}, version = {}, saveType = {}, saveFlag = {}, saveCfg = {}, token = {}", isMobile, fileId, userId, fdMode, version, saveType, saveFlag, saveCfg, token);
            }
        }
        final List<String> saveCfgs = Arrays.asList(saveCfg.split(";"));
        if (!"autoSave".equalsIgnoreCase(saveFlag) && !"rpc save".equalsIgnoreCase(saveFlag) && !"rollbackByVersion".equalsIgnoreCase(saveFlag) && !isMobile && !saveCfgs.contains(saveFlag)) {
            response.setStatus(500);
            return this.buildErrResult(40007, "", "", ResourceUtil.getString("attachment.config.wpsCenterV6SaveTypes.onSaveFile.warn", "sys-attachment"));
        }
        if (!this.getWpsCenterProvider().isV6TokenValid(userId, token, fdMode)) {
            return this.buildErrResult(40003, "用户无权限访问", "用户无权限访问", null);
        }
        final JSONObject params = new JSONObject();
        params.put("fdId", (Object)fileId);
        params.put("userId", (Object)userId);
        params.put("file", (Object)file);
        params.put("fdMode", (Object)fdMode);
        params.put("token", (Object)token);
        params.put("version", (Object)version);
        params.put("saveFlag", (Object)saveFlag);
        params.put("saveCfg", (Object)saveCfg);
        params.put("isMobile", (Object)isMobile);
        final ThirdSfsResponseResult result = this.getSysAttStandardThirdRestService(request).save(params);
        if (SysAttWpsCenterV6Controller.logger.isDebugEnabled()) {
            SysAttWpsCenterV6Controller.logger.debug("WPS中台回调保存文件完成, result = {}", JSONObject.toJSONString((Object)result));
        }
        if ("rollbackByVersion".equalsIgnoreCase(saveFlag)) {
            SysAttWpsCenterV6Controller.logger.warn("用户操作WPS中台恢复到指定历史版本完成, result = {}", JSONObject.toJSONString((Object)result));
        }
        return result.getData();
    }
    
    @PostMapping({ "/integrate/dispatch" })
    public Object dispatch(final HttpServletRequest request, @RequestBody final JSONObject params) throws Exception {
        ((SysAttExtendWpsCenterV6RestService)this.getSysAttExtendThirdRestService(request)).dispatch(params);
        return null;
    }
    
    @GetMapping({ "/audit/show" })
    public void auditShowHtml(final HttpServletRequest request, final HttpServletResponse response) throws Exception {
        final String controlId = request.getParameter("controlId");
        final String userId = request.getParameter("userId");
        final String key = request.getParameter("key");
        final String si = request.getParameter("si");
        if (SysAttWpsCenterV6Controller.logger.isDebugEnabled()) {
            SysAttWpsCenterV6Controller.logger.debug("WPS中台回调下载审批意见控件html开始, controlId = {}, userId = {}, key = {}, si = {}", controlId, userId, key, si);
        }
        if (!this.getWpsCenterProvider().isV6DownloadTokenValid(userId, controlId, key, si)) {
            if (SysAttWpsCenterV6Controller.logger.isDebugEnabled()) {
                SysAttWpsCenterV6Controller.logger.debug("WPS中台回调下载审批意见控件html失败, 无效的下载请求 controlId={}, userId={}, key={}, si={}", controlId, userId, key, si);
            }
            response.setStatus(401);
            return;
        }
        final JSONObject params = new JSONObject();
        params.put("controlId", (Object)controlId);
        params.put("fdModelId", (Object)request.getParameter("fdModelId"));
        params.put("extendFilePath", (Object)request.getParameter("extendFilePath"));
        params.put("userId", (Object)userId);
        params.put("request", (Object)request);
        params.put("response", (Object)response);
        ((SysAttExtendWpsCenterV6RestService)this.getSysAttExtendThirdRestService(request)).auditShowHtml(params);
        if (SysAttWpsCenterV6Controller.logger.isDebugEnabled()) {
            SysAttWpsCenterV6Controller.logger.debug("WPS中台回调下载审批意见控件html完成, controlId = {}, userId= {}, si = {}", controlId, userId, si);
        }
    }
    
    @PostMapping({ "/expiring" })
    public void expiring(final HttpServletRequest request, final HttpServletResponse response) throws Exception {
        final StringBuilder jb = new StringBuilder();
        String line = null;
        Throwable t = null;
        try {
            final BufferedReader reader = request.getReader();
            try {
                while ((line = reader.readLine()) != null) {
                    jb.append(line);
                }
                final JSONObject params = JSONObject.parseObject(jb.toString());
                ((SysAttExtendWpsCenterV6RestService)this.getSysAttExtendThirdRestService(request)).expiring(params);
            }
            finally {
                if (reader != null) {
                    reader.close();
                }
            }
        }
        finally {
            if (t == null) {
                final Throwable exception;
                t = exception;
            }
            else {
                final Throwable exception;
                if (t != exception) {
                    t.addSuppressed(exception);
                }
            }
        }
    }
    
    @PostMapping({ "/v1/3rd/onnotify" })
    public Object onnotify(final HttpServletRequest request, final HttpServletResponse response, @RequestParam(value = "cmd", required = false) final String cmd, @RequestParam(value = "body", required = false) final JSONObject requestBody) {
        final JSONObject result = new JSONObject();
        result.put("result", (Object)0);
        return result;
    }
    
    @PostMapping({ "/v1/3rd/file/view/notify" })
    public Object viewNotify(final HttpServletRequest request, final HttpServletResponse response, @RequestParam(value = "cmd", required = false) final String cmd, @RequestParam(value = "body", required = false) final JSONObject requestBody) {
        final JSONObject result = new JSONObject();
        result.put("result", (Object)0);
        return result;
    }
    
    @PostMapping({ "/v1/3rd/file/online" })
    public Object online(final HttpServletRequest request, final HttpServletResponse response, @RequestParam(value = "ids", required = false) final String[] ids) {
        final JSONObject result = new JSONObject();
        result.put("result", (Object)0);
        return result;
    }
    
    @PostMapping({ "/v1/3rd/file/history" })
    public Object historyList(final HttpServletRequest request, final HttpServletResponse response, @RequestBody final JSONObject params) throws Exception {
        final String fileId = request.getHeader("X-Weboffice-File-Id");
        final String token = request.getHeader("X-Wps-Weboffice-Token");
        final String userId = request.getParameter("_w_third_userId");
        final String fdMode = request.getParameter("_w_third_fdMode");
        if (SysAttWpsCenterV6Controller.logger.isDebugEnabled()) {
            SysAttWpsCenterV6Controller.logger.debug("WPS中台回调分页获取所有历史文件信息开始, fileId = {}, userId= {}, fdMode = {}, params = {}, token = {}", fileId, userId, fdMode, JSONObject.toJSONString((Object)params), token);
        }
        if (!this.getWpsCenterProvider().isV6TokenValid(userId, token, fdMode)) {
            return this.buildErrResult(40003, "用户无权限访问", "用户无权限访问", null);
        }
        params.put("fileId", (Object)fileId);
        params.put("userId", (Object)userId);
        final ThirdSfsResponseResult result = ((SysAttExtendWpsCenterV6RestService)this.getSysAttExtendThirdRestService(request)).historyList(params);
        if (SysAttWpsCenterV6Controller.logger.isDebugEnabled()) {
            SysAttWpsCenterV6Controller.logger.debug("WPS中台回调分页获取所有历史文件信息结束, result = {}", JSONObject.toJSONString((Object)result));
        }
        return result.getData();
    }
    
    @GetMapping({ "/v1/3rd/file/version/{version}" })
    public Object historyVer(final HttpServletRequest request, final HttpServletResponse response, @PathVariable final Integer version) throws Exception {
        final String fileId = request.getHeader("X-Weboffice-File-Id");
        final String token = request.getHeader("X-Wps-Weboffice-Token");
        final String userId = request.getParameter("_w_third_userId");
        final String fdMode = request.getParameter("_w_third_fdMode");
        if (SysAttWpsCenterV6Controller.logger.isDebugEnabled()) {
            SysAttWpsCenterV6Controller.logger.debug("WPS中台回调获取指定历史版本文件开始, fileId = {}, userId= {}, fdMode = {}, version = {}, token = {}", fileId, userId, fdMode, version, token);
        }
        if (!this.getWpsCenterProvider().isV6TokenValid(userId, token, fdMode)) {
            return this.buildErrResult(40003, "用户无权限访问", "用户无权限访问", null);
        }
        final JSONObject params = new JSONObject();
        params.put("userId", (Object)userId);
        params.put("fileId", (Object)fileId);
        params.put("version", (Object)version);
        final ThirdSfsResponseResult result = ((SysAttExtendWpsCenterV6RestService)this.getSysAttExtendThirdRestService(request)).historyVer(params);
        if (SysAttWpsCenterV6Controller.logger.isDebugEnabled()) {
            SysAttWpsCenterV6Controller.logger.debug("WPS中台回调获取指定历史版本文件结束, result = {}", JSONObject.toJSONString((Object)result));
        }
        return result.getData();
    }
    
    private ISysAttachmentWpsCenterOfficeProvider getWpsCenterProvider() {
        if (this.wpsCenterProvider == null) {
            this.wpsCenterProvider = (ISysAttachmentWpsCenterOfficeProvider)SpringBeanUtil.getBean("wpsCenterProvider");
        }
        return this.wpsCenterProvider;
    }
}
